@@ -13,6 +13,7 @@ import re
 import imp
 from optparse import OptionParser, Values
 from cStringIO import StringIO
+from version import __version__
 
 import yaml
 
@@ -56,8 +57,7 @@ def get_parsed_args():
 
 
 def get_version():
-    return "1.0.2"
-
+    return __version__
 
 def skip_leading_wsp(f):
     "Works on a file, returns a file-like object"
@@ -826,23 +826,24 @@ def get_mon_api_config(config):
                       'password': False,
                       'use_keystone': False,
                       'keystone_url': '',
-                      'mapping_file': '',
                       'dimensions': None}
 
     if config.has_option("Main", "dimensions"):
         # parse comma separated dimensions into a dimension list
-        dim_list = [dim.split(':') for dim in config.get('Main', 'dimensions').split(',')]
-        mon_api_config['dimensions'] = {key.strip(): value.strip() for key, value in dim_list}
+        try:
+            dim_list = [dim.split(':') for dim in config.get('Main', 'dimensions').split(',')]
+            mon_api_config['dimensions'] = {key.strip(): value.strip() for key, value in dim_list}
+        except ValueError:
+            mon_api_config['dimensions'] = { }
+
 
     if config.has_section("Api"):
-        options = {"use_mon_api": config.getboolean,
-                   "url": config.get,
+        options = {"url": config.get,
                    "project_id": config.get,
                    "username": config.get,
                    "password": config.get,
                    "use_keystone": config.getboolean,
-                   "keystone_url": config.get,
-                   "mapping_file": config.get}
+                   "keystone_url": config.get}
 
         for name, func in options.iteritems():
             if config.has_option("Api", name):
